==> dom-lite-0.3.9.tgz: package/README.md <==
[1]: https://secure.travis-ci.org/litejs/dom-lite.png
[2]: https://travis-ci.org/litejs/dom-lite
[3]: https://coveralls.io/repos/litejs/dom-lite/badge.png
[4]: https://coveralls.io/r/litejs/dom-lite
[npm package]: https://npmjs.org/package/dom-lite
[GitHub repo]: https://github.com/litejs/dom-lite


    @version    0.3.9
    @date       2015-02-04
    @stability  2 - Unstable


DOM lite &ndash; [![Build][1]][2] [![Coverage][3]][4]
========

A small DOM implementation
where most of DOM attributes and methods are implemented.


Examples
--------

```javascript
var document = require("dom-lite").document;

var el = document.createElement("h1");
el.id = 123;
el.className = "large";

var fragment = document.createDocumentFragment();
var text1 = document.createTextNode("hello");
var text2 = document.createTextNode(" world");

fragment.appendChild(text1);
fragment.appendChild(text2);
el.appendChild(fragment);

el.toString();
// <h1 id="123" class="large">hello world</h1>
el.outerHTML;
// <h1 id="123" class="large">hello world</h1>
el.innerHTML;
// hello world
```

Implementation notes
--------------------

 -  `innerHTML` and `outerHTML` are read only.
 -  Some CSS3 features have not been currently implemented, eg. `:not()` `:nth-child(n)`
    You can use `* body > #id.class:checked:first-child + div:last-child`
-   Supports CSS2 attribute presence and value selectors
    `[att]` `[att=val]` `[att~=val]` `[att|=val]`
-   Supports CSS3 substring matching attribute selectors
    `[att^=val]` `[att$=val]` `[att*=val]`



Coding Style Guidelines
-----------------------

-   Use tabs for indentation, align with spaces
-   Use lowerCamelCase for method and variable names
-   Use UpperCamelCase for constructor names
-   Commit files with Unix-style line endings
-   Do not use spaces in file and directory names
    Consider substituting a dash (-) where you would normally use spaces.
-   Rebase before pushing
-   Fix tests before push or pull request


External links
--------------

-   [GitHub repo][]
-   [npm package][]
-   [DOM spec](https://dom.spec.whatwg.org/)
-   [Selectors Level 3](http://www.w3.org/TR/selectors/)



### Licence

Copyright (c) 2014-2015 Lauri Rooden &lt;lauri@rooden.ee&gt;  
[The MIT License](http://lauri.rooden.ee/mit-license.txt)

==> dom-lite-0.5.1.tgz: package/README.md <==
[1]: https://secure.travis-ci.org/litejs/dom-lite.png
[2]: https://travis-ci.org/litejs/dom-lite
[3]: https://coveralls.io/repos/litejs/dom-lite/badge.png
[4]: https://coveralls.io/r/litejs/dom-lite
[npm package]: https://npmjs.org/package/dom-lite
[GitHub repo]: https://github.com/litejs/dom-lite


    @version    0.5.1
    @date       2016-07-26
    @stability  2 - Unstable


DOM lite &ndash; [![Build][1]][2] [![Coverage][3]][4]
========

A small DOM implementation
where most of DOM attributes and methods from document are implemented.


Examples
--------

```javascript
var document = require("dom-lite").document;

var el = document.createElement("h1");
el.id = 123;
el.className = "large";

var fragment = document.createDocumentFragment();
var text1 = document.createTextNode("hello");
var text2 = document.createTextNode(" world");

fragment.appendChild(text1);
fragment.appendChild(text2);
el.appendChild(fragment);

el.innerHTML;
// hello world
el.innerHTML = "<b>hello world</b>"
el.outerHTML;
// <h1 id="123" class="large"><b>hello world</b></h1>
el.querySelectorAll("b");
// [ "<b>hello world</b>" ]
```


Coding Style Guidelines
-----------------------

-   Use tabs for indentation, align with spaces
-   Use lowerCamelCase for method and variable names
-   Use UpperCamelCase for constructor names
-   Commit files with Unix-style line endings
-   Do not use spaces in file and directory names
    Consider substituting a dash (-) where you would normally use spaces.
-   Rebase before pushing
-   Fix tests before push or pull request


External links
--------------

-   [GitHub repo][]
-   [npm package][]
-   [DOM spec](https://dom.spec.whatwg.org/)
-   [Selectors Level 3](http://www.w3.org/TR/selectors/)



### Licence

Copyright (c) 2014-2016 Lauri Rooden &lt;lauri@rooden.ee&gt;  
[The MIT License](http://lauri.rooden.ee/mit-license.txt)
